# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/micrograd2023',
                'doc_host': 'https://hdocmsu.github.io',
                'git_url': 'https://github.com/hdocmsu/micrograd2023/',
                'lib_path': 'micrograd2023'},
  'syms': { 'micrograd2023.engine': { 'micrograd2023.engine.Value': ('engine.html#value', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__add__': ('engine.html#value.__add__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__init__': ('engine.html#value.__init__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__mul__': ('engine.html#value.__mul__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__neg__': ('engine.html#value.__neg__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__pow__': ('engine.html#value.__pow__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__radd__': ('engine.html#value.__radd__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__repr__': ('engine.html#value.__repr__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__rmul__': ('engine.html#value.__rmul__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__rsub__': ('engine.html#value.__rsub__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__rtruediv__': ( 'engine.html#value.__rtruediv__',
                                                                                   'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__sub__': ('engine.html#value.__sub__', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.__truediv__': ( 'engine.html#value.__truediv__',
                                                                                  'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.backward': ('engine.html#value.backward', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.exp': ('engine.html#value.exp', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.log': ('engine.html#value.log', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.relu': ('engine.html#value.relu', 'micrograd2023/engine.py'),
                                      'micrograd2023.engine.Value.tanh': ('engine.html#value.tanh', 'micrograd2023/engine.py')},
            'micrograd2023.nn': { 'micrograd2023.nn.Layer': ('nn.html#layer', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Layer.__call__': ('nn.html#layer.__call__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Layer.__init__': ('nn.html#layer.__init__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Layer.__repr__': ('nn.html#layer.__repr__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Layer.parameters': ('nn.html#layer.parameters', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.MLP': ('nn.html#mlp', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.MLP.__call__': ('nn.html#mlp.__call__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.MLP.__init__': ('nn.html#mlp.__init__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.MLP.__repr__': ('nn.html#mlp.__repr__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.MLP.parameters': ('nn.html#mlp.parameters', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Module': ('nn.html#module', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Module.parameters': ('nn.html#module.parameters', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Module.zero_grad': ('nn.html#module.zero_grad', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Neuron': ('nn.html#neuron', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Neuron.__call__': ('nn.html#neuron.__call__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Neuron.__init__': ('nn.html#neuron.__init__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Neuron.__repr__': ('nn.html#neuron.__repr__', 'micrograd2023/nn.py'),
                                  'micrograd2023.nn.Neuron.parameters': ('nn.html#neuron.parameters', 'micrograd2023/nn.py')},
            'micrograd2023.utils': { 'micrograd2023.utils.draw_dot': ('utils.html#draw_dot', 'micrograd2023/utils.py'),
                                     'micrograd2023.utils.trace': ('utils.html#trace', 'micrograd2023/utils.py')}}}
